# Contributing

Thank you! :-)


## Bugs and Features

## Qeustions and Suggestions 

## Use Cases and Documentation

## Hosting a Node Package


# How to PR


TODO:
- when / how to build the documentation, how tests and builds are run, badges etc...
- fill in the above notes (see also the main index.md for an exsiting paragraph on contibutions)


```{eval-rst}
.. toctree::
    :maxdepth: 2

    
```

